@@ -221,7 +221,10 @@ mod tests {
         );
 
         let text_svg = r#"<text x="10" y="10" text-anchor="middle" font-size="10" font-weight="bold" fill='#FF0000' >hello world</text>"#;
-        let drawing_svg = format!(r#"<svg viewBox="-0 -0 0 0">{}</svg>"#, text_svg);
+        let drawing_svg = format!(
+            r#"<svg width="0px" height="0px" viewBox="-0 -0 0 0">{}</svg>"#,
+            text_svg
+        );
 
         assert_eq!(drawing.shapes()[0].to_svg().unwrap(), text_svg);
         assert_eq!(drawing.to_svg().unwrap(), drawing_svg);
@@ -236,7 +239,10 @@ mod tests {
                 .with_fill(Fill::Color(Color::U32(0xFF0000))),
         );
         let line_svg = r#"<line x1="10" y1="10" x2="20" y2="20" fill='#FF0000' />"#;
-        let drawing_svg = format!(r#"<svg viewBox="-0 -0 0 0">{}</svg>"#, line_svg);
+        let drawing_svg = format!(
+            r#"<svg width="0px" height="0px" viewBox="-0 -0 0 0">{}</svg>"#,
+            line_svg
+        );
         assert_eq!(drawing.shapes()[0].to_svg().unwrap(), line_svg);
         assert_eq!(drawing.to_svg().unwrap(), drawing_svg);
     }
